<!-- Thanks for your contribution! -->

# Description

## Breaking changes
> List any changes that break the API usage supported on `master`.

# Relevant issues
> List [GitHub issues](https://github.com/lukasschwab/arxiv.py/issues) relevant to this change.

# Checklist

- [ ] (If appropriate) `README.md` example usage has been updated.
